@@ -1,7 +1,3 @@
-# Copyright (c) 2010-2019 Martin Becker, Blaubeuren.
-# This package is free software; you can distribute it and/or modify it
-# under the terms of the Artistic License 2.0 (see LICENSE file).
-
 package Math::ModInt::Event;
 
 use 5.006;
@@ -20,7 +16,7 @@ BEGIN {
         LoadingFailure UndefinedResult DifferentModuli
     );
     our @CARP_NOT   = qw(Math::ModInt);
-    our $VERSION    = '0.012';
+    our $VERSION    = '0.013';
 }
 
 # Math::ModInt::Event=ARRAY(...)
@@ -84,7 +80,7 @@ Math::ModInt::Event - managing events triggered by Math::ModInt
 
 =head1 VERSION
 
-This documentation refers to version 0.012 of Math::ModInt::Event.
+This documentation refers to version 0.013 of Math::ModInt::Event.
 
 =head1 SYNOPSIS
 
@@ -268,11 +264,11 @@ a constructor that can explicitly be imported.
 =head1 DIAGNOSTICS
 
 Standard warnings print C<"warning:"> and the name of the event
-(like C<"undefined result">) on stderr, followed by a caller source
+(like C<"undefined result">) on STDERR, followed by a caller source
 code location.
 
 Standard error messages print C<"error:"> and the name of the event
-(like C<"undefined result">) on stderr, followed by a caller source
+(like C<"undefined result">) on STDERR, followed by a caller source
 code location.  Unless caught in an C<eval> block, program execution
 stops thereafter.
 
@@ -297,11 +293,11 @@ L<Math::ModInt>
 
 =head1 AUTHOR
 
-Martin Becker, E<lt>becker-cpan-mp@cozap.comE<gt>
+Martin Becker, E<lt>becker-cpan-mp I<at> cozap.comE<gt>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2010-2019 Martin Becker, Blaubeuren.
+Copyright (c) 2010-2021 Martin Becker, Blaubeuren.
 
 This library is free software; you can distribute it and/or modify it
 under the terms of the Artistic License 2.0 (see LICENSE file).
